Index: client/dom/scripts/idlparser.py |
diff --git a/client/dom/scripts/idlparser.py b/client/dom/scripts/idlparser.py |
index 5abb4334541c088d38c9ea06e3b7587f5873a72a..643285695766ed02b17adbaa2ad1c3d60df63d08 100755 |
--- a/client/dom/scripts/idlparser.py |
+++ b/client/dom/scripts/idlparser.py |
@@ -288,7 +288,7 @@ class IDLParser(object): |
def _NullableType(): |
return [OR(_IntegerType, BooleanType, OctetType, FloatType, |
DoubleType, SequenceType, DOMStringListType, ScopedName), |
MAYBE(Nullable)] |
def Nullable(): |
@@ -350,7 +350,7 @@ class IDLParser(object): |
def ScopedName(): |
return re.compile(r'[\w\_\:\.\<\>]+') |
- def DOMStringListType(): |
+ def DOMStringArrayType(): |
return 'DOMString[]' |
# Extended Attributes: |
@@ -288,7 +288,7 @@ class IDLParser(object): |
def _NullableType(): |
return [OR(_IntegerType, BooleanType, OctetType, FloatType, |
- DoubleType, SequenceType, DOMStringListType, ScopedName), |
+ DoubleType, SequenceType, DOMStringArrayType, ScopedName), |
MAYBE(Nullable)] |
def Nullable(): |